library(lme4)
library(sjPlot)

x <- read.csv('study1.anon.csv')

# set factor reference levels
x <- within(x, race <- relevel(race, ref = 'B'))
x <- within(x, gender <- relevel(gender, ref = 'M'))
x <- within(x, officer_race <- relevel(officer_race, ref = 'W'))
x <- within(x, result <- relevel(result, ref='warning'))
x$Officer_ID <- as.factor(x$Officer_ID)

# collapse officer races into W, B, and other
x.WBoff <- x[which(x$officer_race == 'W' | x$officer_race == 'B'),]
x.Ooff<- subset(x, officer_race != 'B' & officer_race != 'W')
x.Ooff$officer_race <- 'O'
x <- rbind(x.WBoff, x.Ooff)

# run models
resp <- lmer(scale(Respect) ~ (1 | Officer_ID / Stop_ID) + result + officer_race*race + searched + age + gender, data=x)
form <- lmer(scale(Formality) ~ (1 | Officer_ID / Stop_ID) + result + officer_race*race + searched + age + gender, data=x)

# make html table of results, using wald approximation for p values and showing standardized coefficients 
sjt.lmer(resp, form, p.kr=F, show.est=F, show.std=T)

