import pandas as pd
import statsmodels.formula.api as smf

def forward_selected(data, response):
    #http://planspace.org/20150423-forward_selection_with_statsmodels/
    """Linear model designed by forward selection.

    Parameters:
    -----------
    data : pandas DataFrame with all possible predictors and response
    response: string, name of response column in data

    Returns:
    --------
    model: an "optimal" fitted statsmodels linear model
           with an intercept
           selected by forward selection
           evaluated by adjusted R-squared
    """
    remaining = set(data.columns)
    remaining.remove(response)
    selected = []
    current_score, best_new_score = 0.0, 0.0
    iters = 0
    while remaining and current_score == best_new_score:
        iters += 1
        if iters > 40: break
        scores_with_candidates = []
        for candidate in remaining:
            formula = "{} ~ {} + 1".format(response,
                                           ' + '.join(selected + [candidate]))
            score = smf.ols(formula, data).fit().rsquared_adj
            scores_with_candidates.append((score, candidate))
        scores_with_candidates.sort()
        best_new_score, best_candidate = scores_with_candidates.pop()
        if current_score < best_new_score:
            remaining.remove(best_candidate)
            selected.append(best_candidate)
            current_score = best_new_score
        
    formula = "{} ~ {} + 1".format(response,
                                   ' + '.join(selected))
    model = smf.ols(formula, data).fit()
    return model, formula


if __name__ == '__main__':

    X = pd.read_csv('study2.csv')

    y = {'Respect': X['Respect'],
         'Formality': X['Formality']}
    del X['Respect']
    del X['Formality']

    X = X.loc[:, (X != 0).any(axis=0)] # remove columns with only zeroes; in our training data only the 'goodbye' feature does not occur
    for category in y:
        print '\n\n---- Model for %s ----' %category.upper()
        X[category] = y[category]
        model, formula = forward_selected(X, category)
        print model.summary()
        del X[category]
