library(lme4)
library(sjPlot)

X<-read.csv('study3.anon.csv')

# set factor reference levels
x <- within(x, race <- relevel(race, ref = 'B'))
x <- within(x, gender <- relevel(gender, ref = 'M'))
x <- within(x, officer_race <- relevel(officer_race, ref = 'W'))
x <- within(x, result <- relevel(result, ref='warning'))
x$Officer_ID <- as.factor(x$Officer_ID)
x$tract_crime <- as.numeric(x$tract_crime)

# collapse officer races into W, B, and other
x.WBoff <- x[which(x$officer_race == 'W' | x$officer_race == 'B'),]
x.Ooff<- subset(x, officer_race != 'B' & officer_race != 'W')
x.Ooff$officer_race <- 'O'
x <- rbind(x.WBoff, x.Ooff)



# SI 4.1, main model
resp <- lmer(Respect ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + officer_race * race, data=x)
form <- lmer(Formality ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + officer_race * race, data=x)
#sjt.lmer(resp, form, p.kr=F, show.est=F, show.std=T)




# SI 4.2, Respect and Formality Over Time
#Respect (contrast code race for overall effect):

# Intercept-Only
GCR_NoSlope <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(1| Stop_ID), data=x,contrasts = list(race = contr.sum))
# Random slope for time (growth curve)
#GCR <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(usable_position| Stop_ID), data=x,contrasts = list(race = contr.sum))
GCR <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(usable_position| Stop_ID), data=x)

# Test for sig random slopes
anova(GCR, GCR_NoSlope)
summary(GCR)
confint(GCR)

sjt.lmer(GCR)

# Fixed effect of time for White
GCR_W <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(usable_position| Stop_ID), data=x)
sjt.lmer(GCR_W)

confint(GCR_W)
summary(GCR_W)

# Fixed effect of time for Black
x$race=(relevel(x$race,ref="B"))
GCR_B <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(usable_position| Stop_ID), data=x)
sjt.lmer(GCR_B)

confint(GCR_B)
summary(GCR_B)
x$race=(relevel(x$race,ref="W"))

## Reproduces Table in SI 4.2 that summarizes results when race is dummy coded 0=Black, 1=White
x$race=relevel(x$race,ref="B")
GC_R_B <- lmer((Respect) ~ race*scale(usable_position,scale=F)+(usable_position| Stop_ID), data=x)
summary(GC_R_B)
confint(GC_R_B)
sjt.lmer(GC_R_B)

GC_F_B <- lmer((Formality) ~ race*scale(usable_position,scale=F)+(1| Stop_ID), data=x)
summary(GC_F_B)
confint(GC_F_B)
sjt.lmer(GC_F_B)




# SI 4.4.1, additional covariate
x.addl <- x
x.addl$stop_type <- NULL
x.addl$severity <- NULL
x.addl <- x.addl[complete.cases(x.addl),] # remove small number for which we're missing this metadata
resp.addl <- lmer(Respect ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + officer_race * race + scale(tract_crime_bypop) + scale(officer_yearsexp) + scale(businesscount_sqmile) + raceknown, data=x)
form.addl <- lmer(Formality ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + officer_race * race + scale(tract_crime_bypop) + scale(officer_yearsexp) + scale(businesscount_sqmile) + raceknown, data=x)
#sjt.lmer(resp.addl, form.addl, p.kr=F, show.est=F, show.std=T)

# SI 4.4.2, infraction severity
x.severity <- x[complete.cases(x),] # 
resp.severity <- lmer(Respect ~ (1| Officer_ID / Stop_ID) + searched + severity + gender + result + age + officer_race * race, data=x.severity)
form.severity <- lmer(Formality ~ (1| Officer_ID / Stop_ID) + searched + severity + gender + result + age + officer_race * race, data=x.severity)
#sjt.lmer(resp.severity, form.severity, p.kr=F, show.est=F, show.std=T)

# SI 4.4.3, 'everyday stops' (no arrest, no search)
x.everyday <- subset(x, result != 'arrest' & searched != 1)
resp.everyday <- lmer(Respect ~ (1| Officer_ID / Stop_ID) + gender + result + age + officer_race * race, data=x.everyday)
form.everyday <- lmer(Formality ~ (1| Officer_ID / Stop_ID) + gender + result + age + officer_race * race, data=x.everyday)
#sjt.lmer(resp.everyday, form.everyday, p.kr=F, show.est=F, show.std=T)

# SI 4.4.4, racial homophily
x$race_homophily = as.factor(as.character(x$officer_race) == as.character(x$race))
resp.homophily <- lmer(Respect ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + race * race_homophily, data=x)
form.homophily <- lmer(Formality ~ (1| Officer_ID / Stop_ID) + searched + gender + result + age + race * race_homophily, data=x)
#sjt.lmer(resp.homophily, form.homophily, p.kr=F, show.est=F, show.std=T)




